![playful](http://vincentberenz.is.tuebingen.mpg.de/export/playful_logo.png)


# What this is

Playful is an interpreter for reactive programming applied to robotics.

See : [Playful IEEE RAM](https://ieeexplore.ieee.org/stamp/stamp.jsp?arnumber=8357389)


# Installation

```bash
pip install playful
```

# Usage

For a full tutorial, visit: [playful tutorial](https://github.com/vincentberenz/playful_tutorial)

# Hello world

In a terminal:

```bash
git clone https://github.com/vincentberenz/playful.git
cd playful/hello_world
playful execute
```

# Rapid overview

See: [overview](https://github.com/vincentberenz/playful_tutorial/wiki/00.-Overview)

# Licensing

GPL v3

# Credits

Playful has been developed at the Max Planck Institute for Intelligent Systems, Tuebingen, Germany
